==> haskell-constraints-0.13-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints
version:              0.13
visibility:           public
id:                   constraints-0.13-Clw289cxYY4CE8l3InVY7J
key:                  constraints-0.13-Clw289cxYY4CE8l3InVY7J
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  1bfca42d3c05a5ddf15a9416cd098161
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-8.10.4/site-local/constraints-0.13
library-dirs:         /usr/lib/ghc-8.10.4/site-local/constraints-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/constraints-0.13
hs-libraries:         HSconstraints-0.13-Clw289cxYY4CE8l3InVY7J
depends:
    base-4.14.1.0 binary-0.8.8.0 deepseq-1.4.4.0 ghc-prim-0.6.1
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    type-equality-1-7CHOwuJCivr9KRetNRqfiu

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.13-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints
version:              0.13
visibility:           public
id:                   constraints-0.13-Ax6Z8MifbQbB4DdF5S8wh6
key:                  constraints-0.13-Ax6Z8MifbQbB4DdF5S8wh6
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  6fd7c002b1be1797679e6bb01fc91f5b
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-8.10.4/site-local/constraints-0.13
library-dirs:         /usr/lib/ghc-8.10.4/site-local/constraints-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/constraints-0.13
hs-libraries:         HSconstraints-0.13-Ax6Z8MifbQbB4DdF5S8wh6
depends:
    base-4.14.1.0 binary-0.8.8.0 deepseq-1.4.4.0 ghc-prim-0.6.1
    hashable-1.3.1.0-3O2Bzk2rCtQQYcJkJ3vPV mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    type-equality-1-7CHOwuJCivr9KRetNRqfiu

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
